from distutils.core import setup

setup(
    name = 'kwak',
    packages=['kwak'],
    version='0.1.1',
    url='https://github.com/alexxromero/kwak_wavelets',
    author='Ben G. Lillard and Alexis Romero',
    author_email='alexir2@uci.edu',
    license='MIT',
    description='Statistical tool for wavelet analysis',
    )
